@@ -106,6 +106,23 @@ public:
 }; //Mode2xxxBestGrayK
 #endif // APDK_EXTENDED_MEDIASIZE
 
+#ifdef APDK_APOLLO2XXX
+//! Apollo2xxxProxy
+/*!
+******************************************************************************/
+class Apollo2xxxProxy : public PrinterProxy
+{
+public:
+    Apollo2xxxProxy() : PrinterProxy(
+        "AP2xxx",                       // family name
+        "APOLLO P-22\0"                                 // Apollo P-22xx series
+    ) {m_iPrinterType = eAP2xxx;}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new Apollo2xxx(pSS); }
+	inline PRINTER_TYPE GetPrinterType() const { return eAP2xxx;}
+	inline unsigned int GetModelBit() const { return 0x4000;}
+};
+#endif
+
 APDK_END_NAMESPACE
 
 #endif  //APDK_APOLLO2xx_H
