@@ -155,7 +155,37 @@ const PrintContext::PaperSizeMetrics PrintContext::PSM[MAX_PAPER_SIZE] =
     // CUSTOM_SIZE
     {
         (float)0.0, (float)0.0,   (float)0.0,  (float)0.0,   (float)0.125
-    }
+    },
+
+	// No. 10 Envelope (4.12 x 9.5 in.)
+	{
+		(float)4.12, (float)9.5, (float)3.875, (float)8.875,  (float)0.125
+	},
+
+	// A2 Envelope (4.37 x 5.75 in.)
+	{
+		(float)4.37, (float)5.75, (float)4.12, (float)5.125,  (float)0.125
+	},
+
+	// C6 Envelope (114 x 162 mm)
+	{
+		(float)4.49, (float)6.38, (float)4.24, (float)5.755,  (float)0.125
+	},
+
+	// DL Envelope (110 x 220 mm)
+	{
+		(float)4.33, (float)8.66, (float)4.08, (float)8.035,  (float)0.125
+	},
+
+	// Japanese Envelope #3 (120 x 235 mm)
+	{
+		(float)4.72, (float)9.25, (float)4.47, (float)8.625,  (float)0.125
+	},
+
+	// Japanese Envelope #4 (90 x 205 mm)
+	{
+		(float)3.54, (float)8.07, (float)3.29, (float)7.445,  (float)0.125
+	}
 #endif
 
 }; //PSM
@@ -434,7 +464,7 @@ DRIVER_ERROR PrintContext::SelectPrintMode
     }
 
     // colormode adjustment
-    if (pens == BLACK_PEN)
+    if (pens == BLACK_PEN || pens == MDL_PEN)
     {
         eColorMode = GREY_K;
     }
@@ -742,6 +772,35 @@ PHOTOTRAY_STATE PrintContext::PhotoTrayEngaged
     }
 } //PhotoTrayEngaged
 
+
+//! Returns TRUE if a hagaki feed is present in printer.
+BOOL PrintContext::HagakiFeedPresent(BOOL bQueryPrinter)
+{
+    if (thePrinter == NULL)
+    {
+        return FALSE;
+    }
+    else
+    {
+        return thePrinter->HagakiFeedPresent(bQueryPrinter);
+    }
+}
+
+#ifdef APDK_AUTODUPLEX
+//!Returns TRUE if duplexer and hagaki feed (combined) unit is present in printer.
+BOOL PrintContext::HagakiFeedDuplexerPresent(BOOL bQueryPrinter)
+{
+    if (thePrinter == NULL)
+    {
+        return FALSE;
+    }
+    else
+    {
+        return thePrinter->HagakiFeedDuplexerPresent(bQueryPrinter);
+    }
+}
+#endif
+
 //~PrintContext
 //! Destroy the print device context
 /*!
@@ -1031,7 +1090,6 @@ DRIVER_ERROR PrintContext::PerformPrinterFunction
 
 } //PerformPrinterFunction
 
-
 /*!
 Returns the enum for the next supported model. This method is used when
 bi-directional communication is missing, or for dynamic querying of the
@@ -1040,21 +1098,19 @@ which will exit when the return value equals UNSUPPORTED. Passing this return
 value to SelectDevice will instantiate this printer object and therefore allow
 further querying of the printers capabilities through other methods in
 PrintContext.
-\param currIdx Caller starts at zero; reference variable is incremented
+\param familyHandle Caller starts at null; reference variable is incremented
 automatically for next call.
 \return A value matching an element of the enum PRINTER_TYPE, which can then
 be passed to other methods such as SelectDevice.
 */
 PRINTER_TYPE PrintContext::EnumDevices
 (
-    unsigned int& currIdx
+    FAMILY_HANDLE& familyHandle
 ) const
 {
-    return DR->EnumDevices(currIdx);
+    return pPFI->EnumDevices(familyHandle);
 } //EnumDevices
 
-
-
 BOOL PrintContext::PrinterFontsAvailable()
 {
 #if defined(APDK_FONTS_NEEDED)
@@ -1626,6 +1682,27 @@ DRIVER_ERROR PrintContext::PagesPrinted
     return thePrinter->PagesPrinted(count);
 } //PagesPrinted
 
+/*!
+This is the method for use to check if the printer support a separate 1 bit black channel
+*/
+BOOL PrintContext::SupportSeparateBlack()
+{
+	if (thePrinter == NULL || CurrentMode == NULL)
+	{
+		return FALSE;
+	}
+	else
+	{
+		if (CurrentMode->dyeCount == 3 || CurrentMode->dyeCount == 6)
+		{
+			return FALSE;
+		}
+		else
+		{
+			return thePrinter->SupportSeparateBlack();
+		}
+	}
+}
 
 #ifdef APDK_AUTODUPLEX
 
@@ -1877,6 +1954,7 @@ is relevant for those printers that have multiple input bins. All other printers
 will ignore the bin number. The typical bin numbers are
     1 - Upper Tray
     4 - Lower Tray
+	5 - Duplexer Hagaki Feed
     7 - Auto Select
 Any value between 1 and 50 is valid where there are more than 2 trays.
 ******************************************************************************/
@@ -1889,6 +1967,15 @@ DRIVER_ERROR PrintContext::SetMediaSource
     if ((num > sourceTrayMax) || (num < sourceTrayMin))
 	     return WARN_INVALID_MEDIA_SOURCE;
     m_MediaSource = num;
+
+	if (thePrinter != NULL)
+	{
+		BOOL bQueryHagakiTray = TRUE;
+		if (num == sourceDuplexerNHagakiFeed && !thePrinter->HagakiFeedPresent(bQueryHagakiTray))
+		{
+			m_MediaSource = sourceTrayAuto;
+		}
+	}
     return NO_ERROR;
 }
 
@@ -1911,84 +1998,4 @@ PEN_TYPE PrintContext::GetInstalledPens()
 	return thePrinter->ePen;
 }
 
-const char* PrintContext::PentypeToString(PEN_TYPE pen)
-{
-	switch(pen)
-	{
-		case BLACK_PEN:
-			return "Black Pen";
-		case COLOR_PEN:
-			return "Color Pen";
-		case BOTH_PENS:
-			return "Both Pens";
-		case MDL_PEN:
-			return "MDL Pen";
-		case MDL_BOTH:
-			return "MDL Both";
-		// no test harness item for these combinations
-		case MDL_AND_BLACK_PENS:
-		case MDL_BLACK_AND_COLOR_PENS:
-		case NO_PEN:
-		case DUMMY_PEN:
-		default:
-			return "No Pen";
-	}
-}
-
-char* PrintContext::PrintModeID()
-{
-	char* res = new char[30];
-	strcpy(res," ");  // so can use strcat from now on
-
-	QUALITY_MODE qm;
-	MEDIATYPE mt;
-	COLORMODE cm;
-	BOOL text;
-
-	GetPrintModeSettings(qm, mt, cm, text);
-
-	switch(qm)
-	{
-	case(QUALITY_NORMAL): strcat(res,"N"); break;
-	case(QUALITY_BEST): strcat(res,"B"); break;
-	case(QUALITY_DRAFT): strcat(res,"D"); break;
-        default: break;
-	}
-	strcat(res," ");
-
-	switch(mt)
-	{
-	case(MEDIA_PLAIN): strcat(res,"P"); break;
-	case(MEDIA_PREMIUM): strcat(res,"C"); break;    // for COATED
-	case(MEDIA_PHOTO): strcat(res,"O"); break;
-        default: break;
-	}
-
-	strcat(res," ");
-
-	switch(cm)
-	{
-	case(COLOR): strcat(res,"C"); break;    
-	case(GREY_K): strcat(res,"G"); break;
-	case(GREY_CMY): strcat(res,"Y"); break;
-        default: break;
-	}
-
-	strcat(res," ");
-
-	if (text)
-	strcat(res,"T");
-	else strcat(res,"N");
-
-	unsigned int index = CurrentMode->myIndex;
-	strcat(res," ");
-	char tmp[3];
-	//	strcat(res,itoa(index,tmp,10));   // itoa is not ANSI C, des
-        sprintf(tmp, "%d", index);
-	strcat(res,tmp);
-
-
-	return res;
-}
-
 APDK_END_NAMESPACE
