@@ -107,6 +107,26 @@ public:
 }; //Mode630BestGrayK
 #endif // APDK_EXTENDED_MEDIASIZE
 
+#ifdef APDK_DJ630
+//! DJ630Proxy
+/*!
+******************************************************************************/
+class DJ630Proxy : public PrinterProxy
+{
+public:
+    DJ630Proxy() : PrinterProxy(
+        "DJ630",                    // family name
+        "DESKJET 63\0"                                  // DeskJet 63x Series
+        "DESKJET 65\0"                                  // DeskJet 65x Series
+#ifdef APDK_MLC_PRINTER
+#endif
+    ) {m_iPrinterType = eDJ630;}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ630(pSS); }
+	inline PRINTER_TYPE GetPrinterType() const { return eDJ630;}
+	inline unsigned int GetModelBit() const { return 0x8000;}
+};
+#endif
+
 APDK_END_NAMESPACE
 
 #endif // APDK_DJ630_H
