@@ -41,31 +41,6 @@ APDK_BEGIN_NAMESPACE
 extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_CMY[ 9 * 9 * 9 ];
-
-//! DJ660Proxy
-/*!
-******************************************************************************/
-static class DJ660Proxy : public PrinterProxy
-{
-public:
-    DJ660Proxy() : PrinterProxy(
-        "DJ6xx",                    // family name
-        "DESKJET 66\0"                          // DeskJet 66x Series
-        "DESKJET 67\0"                          // DeskJet 67x Series
-        "DESKJET 68\0"                          // DeskJet 68x Series
-        "DESKJET 60\0"                           // DeskJet 6xx Series
-        "e-printer e20\0"                       // ePrinter
-#ifdef APDK_MLC_PRINTER
-        "OfficeJet Series 5\0"                  // OfficeJet Series 500
-        "OfficeJet Series 6\0"                  // OfficeJet Series 600
-        "Printer/Scanner/Copier 3\0"            // PSC 300 Series
-        "OfficeJet Series 7\0"                  // OfficeJet Series 700
-#endif
-    ) {}
-    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ660(pSS); }
-} DJ660Proxy;
-
-
 //
 // ** DJ660:Printer CLASS **
 //
@@ -125,8 +100,15 @@ Mode660BestGrayK::Mode660BestGrayK()
 {
    theQuality = qualityPresentation;
    pmQuality = QUALITY_BEST;
-   BaseResX = BaseResY = 600;
-   ResolutionX[0] = ResolutionY[0] = 600;
+   BaseResX = 600;
+   ResolutionX[0] = 600;
+#ifdef APDK_LINUX
+   BaseResY = 600;
+   ResolutionY[0] = 600;
+#else
+   BaseResY = 300;
+   ResolutionY[0] = 300;
+#endif
 }
 #endif // APDK_EXTENDED_MEDIASIZE
 
