@@ -38,32 +38,6 @@
 
 APDK_BEGIN_NAMESPACE
 
-//! DJGenericVIPProxy
-/*!
-******************************************************************************/
-static class DJGenericVIPProxy : public PrinterProxy
-{
-public:
-    DJGenericVIPProxy() : PrinterProxy(
-        "GenericVIP",                       // family name
-        "photosmart 7150\0"                 // Twister
-        "photosmart 7350\0"                 // Dorothy
-		"photosmart 7345\0"                 // Dorothy
-        "photosmart 7550\0"
-        "deskjet 5550\0"
-        "deskjet 5551\0"
-        "dj450\0"
-#ifdef APDK_MLC_PRINTER
-        "PSC 2100\0"
-        "PSC 2150\0"
-        "PSC 2200\0"
-        "OfficeJet 6100\0"              // OfficeJet 6100 Series
-#endif
-    ) {}
-    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJGenericVIP(pSS); }
-} DJGenericVIPProxy;
-
-
 /*
  *  All VIP printers that are released after the APDK release.
  *  This subclass is mainly there to allow any combination of
@@ -71,7 +45,7 @@ public:
  */
 
 DJGenericVIP::DJGenericVIP (SystemServices* pSS, BOOL proto)
-    : DJ9xxVIP (pSS, TRUE)
+    : DJ9xxVIP (pSS, proto)
 {
 
     if (!proto && IOMode.bDevID)
@@ -280,19 +254,72 @@ BOOL DJGenericVIP::FullBleedCapable (PAPER_SIZE ps, FullbleedType  *fbType, floa
 
 PHOTOTRAY_STATE DJGenericVIP::PhotoTrayEngaged (BOOL bQueryPrinter)
 {
-/*
- *  Malibu and its derivatives do not have a phototray sensor, so they don't
- *  report the current state of phototray engagement correctly. Always return
- *  UNKNOWN here.
-    if (((PhotoTrayStatus (bQueryPrinter) & 9) == 9))
-    {
-        return TRUE;
-    }
-    return FALSE;
- */
     return UNKNOWN;
 }
 
+//! Returns TRUE if a hagaki feed is present in printer.
+BOOL DJGenericVIP::HagakiFeedPresent(BOOL bQueryPrinter) 
+{
+    DRIVER_ERROR err;
+    char* pStr;
+
+    BYTE bDevIDBuff[DevIDBuffSize];
+
+    if (!IOMode.bDevID)
+    {
+        bQueryPrinter = FALSE;
+    }
+
+    err = pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, bQueryPrinter);
+    if (err!=NO_ERROR)
+    {
+        return 0;
+    }
+
+    if ( (pStr=(char *)strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
+    {
+        return 0;
+    }
+
+    // skip over ";S:<version=2bytes><topcover><inklid><duplexer>"
+    pStr += 8;
+    BYTE b = *pStr;
+    return (b & 4 == 4);
+}
+
+#ifdef APDK_AUTODUPLEX
+//!Returns TRUE if duplexer and hagaki feed (combined) unit is present in printer.
+BOOL DJGenericVIP::HagakiFeedDuplexerPresent(BOOL bQueryPrinter)
+{
+    DRIVER_ERROR err;
+    char* pStr;
+
+    BYTE bDevIDBuff[DevIDBuffSize];
+
+    if (!IOMode.bDevID)
+    {
+        bQueryPrinter = FALSE;
+    }
+
+    err = pSS->GetDeviceID(bDevIDBuff, DevIDBuffSize, bQueryPrinter);
+    if (err!=NO_ERROR)
+    {
+        return 0;
+    }
+
+    if ( (pStr=(char *)strstr((const char*)bDevIDBuff+2,";S:")) == NULL )
+    {
+        return 0;
+    }
+
+    // skip over ";S:<version=2bytes><topcover><inklid>"
+    pStr += 6;
+    BYTE b = *pStr;
+    return (b & 4 == 4);
+}
+#endif
+
+
 DRIVER_ERROR DJGenericVIP::VerifyPenInfo ()
 {
 
