@@ -92,6 +92,26 @@ public:
     LJMonoBestMode ();
 }; // LJMonoBestMode
 
+#ifdef APDK_LJMONO
+//! LJMonoProxy
+/*!
+******************************************************************************/
+class LJMonoProxy : public PrinterProxy
+{
+public:
+    LJMonoProxy() : PrinterProxy(
+        "Mono Laser",               // family name
+        "HP LaserJet\0"             // models
+		"hp LaserJet\0"             // LaserJet
+#ifdef APDK_MLC_PRINTER
+#endif
+    ) {m_iPrinterType = eLJMono;}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new LJMono(pSS); }
+	inline PRINTER_TYPE GetPrinterType() const { return eLJMono;}
+	inline unsigned int GetModelBit() const { return 0x40;}
+};
+#endif
+
 APDK_END_NAMESPACE
 
 #endif //APDK_LJMono_H
